Convention for associating token accounts with a user wallet
Re-exports
pub use gemachain_program;
Modules
- instruction
- Program instructions
- processor
- Program state processor
- tools
- Utility functions
Statics
- ID
- The static program ID
Functions
- check_
id - Confirms that a given pubkey is equivalent to the program ID
- create_
associated_ token_ account - Create an associated token account for the given wallet address and token mint
- get_
associated_ token_ address - Derives the associated token account address for the given wallet address and token mint
- id
- Returns the program ID